@echo OFF
SETLOCAL EnableDelayedExpansion

rem TF2 CUSTOM SWITCHER V1 by MAID
rem https://tf2maps.net/members/maid.30601/

rem This script switches in and out different custom folders for TF2 depending on a file named 'label.txt' in each folder, which contains a single line of text to represent the folder's label
rem When not in use, each custom folder should be named /tf/custom_label/, with the exact same label string as the contents of the folder's label.txt
rem The label will be searched for as the parameter fed into the SwapIn function in this script
rem The script can be easily edited between the 'EDIT' comments to declare new folders that can be selected

rem Place this script in your /Team Fortress 2/bin/ folder.
rem I suggest using this as your TF2/Hammer shortcut, and editing the :Run function for whichever software you wish to launch after selecting a preset.
rem To run Hammer, do 'start hammerplusplus.exe'.
rem To run TF2, do 'start steam://rungameid/440'.

rem This script is built with a default gameinfo.txt in mind, with the custom folders located in /tf/. If this is not the case on your system, more manual modification may be required.

rem EDIT BELOW THIS

rem present choice to user

echo 1. All Custom Content
echo 2. Minimal Custom Content
echo 3. No Custom Content
echo 4. Minimal Custom Content + Mapping Stuff
echo 5. Thaw
echo.

rem after /C, list all the single character options for input
choice /C 12345 /M "Which Custom to use:"

rem enter new presets in this format
rem if ERRORLEVEL # goto Keyword
rem :Keyword
rem		call :Swapin "keyword"

rem list ERRORLEVELS in decreasing order - the index of the choice character in the previous list becomes the errorlevel.
if ERRORLEVEL 5 goto Thaw
if ERRORLEVEL 4 goto Base
if ERRORLEVEL 3 goto None
if ERRORLEVEL 2 goto Min
if ERRORLEVEL 1 goto All

:All
	call :SwapIn "all"

:Min
	call :SwapIn "min"

:None
	call :SwapIn "none"

:Base
	call :SwapIn "base"

:Thaw
	call :SwapIn "thaw"

:Run
	start hammerplusplus.exe
	exit

:Error
	echo closing this script without continuing, go figure it out.
	pause
	exit

rem EDIT ABOVE THIS

rem Parameters: %~1 is generic reference to parameter given (used in folder name and label file, make all lowercase no spaces no special chars)
:SwapIn
	rem find the existing custom folder
	if exist C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\custom\ (
		rem find the label file in the existing custom folder
		if exist C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\custom\label.txt (
			rem check if it's already the right folder by checking the existing label against the desired label
			set /p Label=<C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\custom\label.txt
			if !Label!==%~1 (
				rem it's already the right folder; we don't need to do anything else
				goto Run
			) else (
				rem it's currently using the wrong folder!
				
				rem first, we need to store the existing tf/custom folder elsewhere by renaming it based on its label
				rem (how we rename it is important, since we'll need to find it again under this name later)
				
				rem construct the folder name out of 'custom' and the Label string
				set FolderName=custom_!Label!
				rem then, rename the existing custom folder to this new folder name
				ren C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\custom\ !FolderName!
				
				rem now, we need to find the folder we want, and swap it in by renaming it to 'custom'
				rem first let's construct the name of the folder we're looking for
				set FolderToSwapIn=custom_%~1
				
				if exist C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\!FolderToSwapIn!\ (
					rem we've found the folder!
					ren C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\!FolderToSwapIn!\ custom
					
					rem that's all done! now, let's quickly check that nothing's gone wrong during that process by ensuring that the custom folder exists and has the right label.
					if exist C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\custom\ (
						if exist C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\custom\label.txt (
							set /p Label=<C:\"Program Files (x86)"\Steam\steamapps\common\"Team Fortress 2"\tf\custom\label.txt
							if !Label!==%~1 (
								rem everything seems fine! no errors were found.
								rem we can run!
								goto Run
							) else (
								rem tf/custom/label.txt contains the wrong text
								echo we've tried to swap in !FolderToSwapIn!, but its label.txt file contains the wrong text; something's gone wrong.
								echo it contains '!Label!', instead of '%~1'.
								goto Error
							)
						) else (
							rem couldnt find tf/custom/label.txt
							echo we've tried to swap in !FolderToSwapIn!, but it doesn't seem to have a label.txt file; something's gone wrong.
							echo it should have a label.txt file containing exactly %~1.
							goto Error
						)
					) else (
						rem couldn't find a tf/custom/ folder
						echo we've tried to swap in !FolderToSwapIn!, but there's no tf/custom folder now; something's gone wrong.
						echo possibly access was denied for some reason?
						goto Error
					)
				) else (		rem can't find the folder we need
					echo tf/custom_%~1 doesn't exist; something's gone wrong.

					goto Error
				)
			)
		) else (
			rem can't find any label file in the custom folder, which is a problem
			echo the existing tf/custom folder has no label.txt file; something's gone wrong.
			goto Error
		)
	) else (
		rem cant find the custom folder
		echo we can't find the tf/custom folder for some reason; something's gone wrong.
		goto Error
	)
